EcpHtml class
@author gehang @since 2024/6/3 19:11
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Html
- EcpHtml
Constructors
Properties
- data → String?
-
The HTML data passed to the widget as a String
finalinherited
- documentElement → Element?
-
The HTML data passed to the widget as a pre-processed
dom.Elementfinalinherited -
doNotRenderTheseTags
→ Set<
String> ? -
A set of HTML tags to completely ignore in the provided code.
finalinherited
-
extensions
→ List<
HtmlExtension> -
A list of
HtmlExtensions that add additional capabilities to flutter_html See theHtmlExtensionclass for more details.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAnchorTap → OnTap?
-
A function that defines what to do when an anchor link is tapped. When this value is set,
the default anchor behaviour is overwritten.
finalinherited
- onCssParseError → OnCssParseError?
-
A function that defines what to do when CSS fails to parse
finalinherited
- onLinkTap → OnTap?
-
A function that defines what to do when a link is tapped
finalinherited
-
onlyRenderTheseTags
→ Set<
String> ? -
A set of the only HTML tags that should be rendered by this widget.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shrinkWrap → bool
-
A parameter that should be set when the HTML widget is expected to be
flexible
finalinherited
-
style
→ Map<
String, Style> -
An API that allows you to override the default style for any HTML element
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited