onCssParseError property
OnCssParseError?
onCssParseError
finalinherited
A function that defines what to do when CSS fails to parse
Implementation
final OnCssParseError? onCssParseError;
A function that defines what to do when CSS fails to parse
final OnCssParseError? onCssParseError;