EcpWidgetPath class

@author lzj

@since 2024/6/12 11:26

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

commonOpinionList → const String
常用意见列表
delCommonOpinion → const String
删除常用意见
saveCommonOpinion → const String
保存常用意见