EcpAvatar class

@author lzj

@since 2023/6/21 10:10

Inheritance

Constructors

EcpAvatar({Key? key, required String imageUrl, required double size, double? radius, Widget? placeholder, Widget? errorImage, Widget? defaultImage, Map<String, String>? httpHeaders, dynamic onChanged(String path, bool local)?, EcpAvatarController? controller, bool supportUpdateAvatar = true, bool supportPreview = false})
const

Properties

controller EcpAvatarController?
final
defaultImage Widget?
final
errorImage Widget?
final
hashCode int
The hash code for this object.
no setterinherited
httpHeaders Map<String, String>?
final
imageUrl String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → dynamic Function(String path, bool local)?
final
placeholder Widget?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
supportPreview bool
final
supportUpdateAvatar bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EcpAvatar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited