EcpCornerMark class

@author lzj

@since 2023/7/17 11:19

Inheritance

Constructors

EcpCornerMark({Key? key, required num number, required Widget child, bool visiblePredict(num)?, String onDisplay(num)?, double size = 15, Color color = Colors.red, double? left, double? right, double? top, double? bottom, Widget markBuilder(BuildContext context, num number)?})
const

Properties

bottom double?
final
child Widget
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
left double?
final
markBuilder Widget Function(BuildContext context, num number)?
final
number num
final
onDisplay String Function(num)?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
top double?
final
visiblePredict bool Function(num)?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited