IndexedTabScrollView class

@author lzj

@since 2024/7/16 10:08

Inheritance

Constructors

IndexedTabScrollView({Key? key, required List<Widget> children, IndexedWidgetBuilder? separatorBuilder, required IndexedWidgetBuilder tabItemBuilder, Color? tabBackgroundColor, bool? isScrollable, EdgeInsetsGeometry? padding, Color? indicatorColor, double? indicatorWeight, EdgeInsetsGeometry? indicatorPadding, Decoration? indicator, bool automaticIndicatorColorAdjustment = true, TabBarIndicatorSize? indicatorSize, Color? dividerColor, Color? labelColor, Color? unselectedLabelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, TextStyle? unselectedLabelStyle, WidgetStateProperty<Color?>? overlayColor, DragStartBehavior? dragStartBehavior, MouseCursor? mouseCursor, bool? enableFeedback, ScrollPhysics? tabPhysics, InteractiveInkFeatureFactory? splashFactory, BorderRadius? splashBorderRadius, EdgeInsets? tabPadding, EdgeInsets? tabMargin, EdgeInsets? scrollViewPadding, ScrollPhysics? scrollPhysics, IndexedWidgetBuilder? headerBuilder, double? space, TabAlignment? tabAlignment})
const

Properties

automaticIndicatorColorAdjustment bool
Whether this tab bar should automatically adjust the indicatorColor.
final
children List<Widget>
final
dividerColor Color?
The color of the divider.
final
dragStartBehavior DragStartBehavior?
Determines the way that drag start behavior is handled.
final
enableFeedback bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
final
hashCode int
The hash code for this object.
no setterinherited
headerBuilder IndexedWidgetBuilder?
final
indicator Decoration?
Defines the appearance of the selected tab indicator.
final
indicatorColor Color?
The color of the line that appears below the selected tab.
final
indicatorPadding EdgeInsetsGeometry?
Padding for indicator. This property will now no longer be ignored even if indicator is declared or provided by TabBarTheme
final
indicatorSize TabBarIndicatorSize?
Defines how the selected tab indicator's size is computed.
final
indicatorWeight double?
The thickness of the line that appears below the selected tab.
final
isScrollable bool?
Whether this tab bar can be scrolled horizontally.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor Color?
The color of selected tab labels.
final
labelPadding EdgeInsetsGeometry?
The padding added to each of the tab labels.
final
labelStyle TextStyle?
The text style of the selected tab labels.
final
mouseCursor MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the individual tab widgets.
final
overlayColor WidgetStateProperty<Color?>?
Defines the ink response focus, hover, and splash colors.
final
padding EdgeInsetsGeometry?
The amount of space by which to inset the tab bar.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics ScrollPhysics?
final
scrollViewPadding EdgeInsets?
final
separatorBuilder IndexedWidgetBuilder?
final
space double?
final
splashBorderRadius BorderRadius?
Defines the clipping radius of splashes that extend outside the bounds of the tab.
final
splashFactory InteractiveInkFeatureFactory?
Creates the tab bar's InkWell splash factory, which defines the appearance of "ink" splashes that occur in response to taps.
final
tabAlignment TabAlignment?
final
tabBackgroundColor Color?
final
tabItemBuilder IndexedWidgetBuilder
final
tabMargin EdgeInsets?
final
tabPadding EdgeInsets?
final
tabPhysics ScrollPhysics?
How the TabBar's scroll view should respond to user input.
final
unselectedLabelColor Color?
The color of unselected tab labels.
final
unselectedLabelStyle TextStyle?
The text style of the unselected tab labels.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<IndexedTabScrollView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited