DUPickerController<U, D> class
Constructors
Properties
-
crumbsList
→ List<
D> -
no setter
- currentDept → D?
-
no setter
-
currentUserList
→ List<
SelectWrapper< U> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- rootDept → D?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searched → bool
-
no setter
-
selectedList
→ List<
U> -
no setter
Methods
-
back(
) → void - 回退
-
canBack(
) → bool - 是否可回退
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
simulateDeptClick(
D department) → void - 模拟点击部门
-
simulateUserSelected(
SelectWrapper< U> wrapper, bool value) → void - 模拟选择用户
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited