EcpUserPicker class

@author lzj

@since 2022/11/28 16:29

选人组件

Inheritance

Constructors

EcpUserPicker({Key? key, int limitNum = noLimit, bool allowEmpty = false, List<User>? selectUserList, bool appBarVisible = true, bool? clickWithoutConfirm = true, String? title, List<String>? indexList, bool? showIndex = false, String? searchHint = '请输入人员名称进行搜索', OnSelected<User>? onSelected, bool showSearch = true, bool? showSelectedList, bool refreshEnable = true, bool loadMoreEnable = true, bool isAutoLeading = true, List<User>? frozenList, bool showCharacter = false, UserSelectorBuilder<User, Department>? userSelectorBuilder, SelectedBuilder<User>? userSelectedBuilder, UserRepo<User, Department>? userRepo, SearchRepo<User, Department>? userSearchRepo, IndexPredicate<User, Department>? indexPredicate, EcpDepartmentRange? range, List<String>? deptIds, int? hideLeaderFlag, int? queryHeadshipName})

Properties

allowEmpty bool
是否允许不选择,如果不允许,则会在返回时提示用户选择
finalinherited
appBarVisible bool
finalinherited
clickWithoutConfirm bool?
finalinherited
controller DUPickerController<User, Department>?
finalinherited
crumbBuilder CrumbBuilder<User, Department>?
finalinherited
departmentBuilder CrumbBuilder<User, Department>?
finalinherited
departmentRepo DepartmentRepo<Department>?
finalinherited
frozenList List<User>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
indexList List<String>?
finalinherited
indexPredicate IndexPredicate<User, Department>?
finalinherited
isAutoLeading bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
limitNum int
选择限制数
finalinherited
loadMoreEnable bool
finalinherited
onBack VoidCallback?
返回按钮回调
finalinherited
onDataChanged VoidCallback?
列表数据改变回调
finalinherited
onParentSelect → dynamic Function(List<Department> parents)?
所有选择路径回调
finalinherited
onSelected OnSelected<User>?
finalinherited
onUserClick OnUserClick<User, Department>?
finalinherited
refreshEnable bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHint String?
finalinherited
searchRepo SearchRepo<User, Department>?
finalinherited
selectUserList List<User>?
finalinherited
separatorBuilder IndexedWidgetBuilder?
finalinherited
showIndex bool?
finalinherited
showSelectedList bool?
finalinherited
title String?
finalinherited
userRepo UserRepo<User, Department>?
finalinherited
userRepoPredication UserRepoPredication<Department>?
用户列表是否可访问
finalinherited
userSelectedBuilder SelectedBuilder<User>?
finalinherited
userSelectorBuilder UserSelectorBuilder<User, Department>?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DepartmentUserPicker<User, Department>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited