UnitPickerItem class
@Author cyh @Description 单位选择item @Date 2023/9/8
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- EcpPickerTileItem<
Department> - UnitPickerItem
Constructors
-
UnitPickerItem({Key? key, required SelectWrapper<
Department> wrapper, IconData? icon = Icons.add_business_rounded, bool showCheckBox = true})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
finalinherited
-
iconBuilder
→ EcpTileIconBuilder<
Department> ? -
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDisplay → String Function(Department)?
-
finalinherited
- onSelected → dynamic Function(bool?)?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCheckBox → bool
-
finalinherited
-
wrapper
→ SelectWrapper<
Department> -
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< EcpPickerTileItem< Department> > -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited