DepartmentUserPicker<U, D> class
@author lzj
@since 2022/8/26 11:13
选人控件
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DepartmentUserPicker
- Implementers
Constructors
-
DepartmentUserPicker({Key? key, int limitNum = noLimit, bool allowEmpty = false, UserSelectorBuilder<
U, D> ? userSelectorBuilder, SelectedBuilder<U> ? userSelectedBuilder, DepartmentBuilder<U, D> ? departmentBuilder, CrumbBuilder<U, D> ? crumbBuilder, DepartmentRepo<D> ? departmentRepo, UserRepo<U, D> ? userRepo, SearchRepo<U, D> ? searchRepo, List<U> ? selectUserList, String? title, bool appBarVisible = true, bool? clickWithoutConfirm = false, dynamic onParentSelect(List<D> parents)?, bool? showIndex = false, List<String> ? indexList, IndexPredicate<U, D> ? indexPredicate, OnSelected<U> ? onSelected, String? searchHint, bool refreshEnable = true, bool loadMoreEnable = true, bool? showSelectedList, bool isAutoLeading = true, List<U> ? frozenList, OnUserClick<U, D> ? onUserClick, UserRepoPredication<D> ? userRepoPredication, VoidCallback? onBack, IndexedWidgetBuilder? separatorBuilder, DUPickerController<U, D> ? controller, VoidCallback? onDataChanged}) -
const
Properties
- allowEmpty → bool
-
是否允许不选择,如果不允许,则会在返回时提示用户选择
final
- appBarVisible → bool
-
final
- clickWithoutConfirm → bool?
-
final
-
controller
→ DUPickerController<
U, D> ? -
final
-
crumbBuilder
→ CrumbBuilder<
U, D> ? -
final
-
departmentBuilder
→ CrumbBuilder<
U, D> ? -
final
-
departmentRepo
→ DepartmentRepo<
D> ? -
final
-
frozenList
→ List<
U> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexList
→ List<
String> ? -
final
-
indexPredicate
→ IndexPredicate<
U, D> ? -
final
- isAutoLeading → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- limitNum → int
-
选择限制数
final
- loadMoreEnable → bool
-
final
- onBack → VoidCallback?
-
返回按钮回调
final
- onDataChanged → VoidCallback?
-
列表数据改变回调
final
-
onParentSelect
→ dynamic Function(List<
D> parents)? -
所有选择路径回调
final
-
onSelected
→ OnSelected<
U> ? -
final
-
onUserClick
→ OnUserClick<
U, D> ? -
final
- refreshEnable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchHint → String?
-
final
-
searchRepo
→ SearchRepo<
U, D> ? -
final
-
selectUserList
→ List<
U> ? -
final
- separatorBuilder → IndexedWidgetBuilder?
-
final
- showIndex → bool?
-
final
- showSelectedList → bool?
-
final
- title → String?
-
final
-
userRepo
→ UserRepo<
U, D> ? -
final
-
userRepoPredication
→ UserRepoPredication<
D> ? -
用户列表是否可访问
final
-
userSelectedBuilder
→ SelectedBuilder<
U> ? -
final
-
userSelectorBuilder
→ UserSelectorBuilder<
U, D> ? -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DepartmentUserPicker< U, D> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited